@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import ast
 import warnings
 
@@ -16,7 +18,7 @@ def ast_to_offset(node: ast.AST) -> Offset:
         candidate = candidates.pop()
         if hasattr(candidate, 'lineno'):
             return Offset(candidate.lineno, candidate.col_offset)
-        elif hasattr(candidate, '_fields'):  # pragma: no cover (<py39)
+        elif hasattr(candidate, '_fields'):  # pragma: <3.9 cover
             for field in reversed(candidate._fields):
                 candidates.append(getattr(candidate, field))
     else:
